@@ -4,6 +4,9 @@ function(surv, id, z) {
   options(warn = -1)
   fit <- try(survdiff(surv ~ z + strata(id)), silent = TRUE)
   options(warn = 0)
-  if (!inherits(fit, "try-error")) { score <- fit$chisq }
+  if (!inherits(fit, "try-error")) {
+    score <- fit$chisq
+    if (length(score) == 0) { score <- NA }
+  }
   score
 }
